.. :changelog:

History
=======

0.1.1 (2017-03-27)
------------------

* Obligatory "foreseeable mistake in setup.py" release. (thx <https://github.com/j-e-d>`_).

0.1.0 (2017-03-27)
------------------

* Initial release on PyPI, incorporating many contributions from `hugovk
  <https://github.com/hugovk>`_.

0.0.1 (2016-03-09)
------------------

* First release on Github.
